A data frame with one column containing the RIF of the interquantile ratio for each observation.
Arguments
dep_var
dependent variable of a distributional function. Discrete or continuous numeric vector.
weights
numeric vector of non-negative observation weights, hence of same length as dep_var.
The default (NULL) is equivalent to weights = rep(1, length(dep_var)).
probs
a vector of length 2 with probabilities corresponding to the quantiles in the ratio's numerator and the denominator.
The function defines the interquantile ratio as the ratio between the quantile with the larger probability (numerator) and
the quantile with the lower probability (denominator).