Function to estimate the recentered influence function (RIF) of the variance
of a weighted distribution of a dependent variable.
Usage
get_rif_variance(dep_var, weights)
Value
A data frame with one column containing the RIF of the variance for each observation and one column containing the weights.
Arguments
dep_var
dependent variable of a distributional function. Discrete or continuous numeric vector.
weights
numeric vector of non-negative observation weights, hence of same length as dep_var.
The default (NULL) is equivalent to weights = rep(1, length(dep_var)).