the size of the area under the lorenz curve (the integrated lorenz curve).
Arguments
dep_var
dependent variable of a distributional function. Discrete or continuous numeric vector.
weights
numeric vector of non-negative observation weights, hence of same length as dep_var.
The default (NULL) is equivalent to weights = rep(1, length(dep_var)).