Learn R Programming

rifreg (version 1.1.0)

summary.rifreg: summary method for class "rifreg"

Description

summary method for class "rifreg"

Usage

# S3 method for rifreg
summary(object, vcov = sandwich::sandwich, ...)

Value

the function summary.rifreg() returns a list of summary statistics derived from the rifreg object given in object. For further details see summary.lm.

Arguments

object

an object of class "rifreg", usually, a result of a call to rifreg.

vcov

Function to estimate covariance matrix of rifreg coefficients if covariance matrix has not been bootstrapped. Per default, heteroscedasticity-consistent (HC) standard errors are calculated using sandwich. Note: These standard errors do not take the variance introduced by estimating RIF into account.

...

other parameters to be passed to summary functions.

Examples

Run this code

rifreg <- rifreg(
  formula = log(wage) ~ union +
    nonwhite +
    married +
    education +
    experience,
  data = men8385,
  statistic = "quantiles",
  probs = seq(0.1, 0.9, 0.1),
  weights = weights
)
summary(rifreg)

Run the code above in your browser using DataLab