A data frame with one column containing the RIF of the interquantile range for each observation and one column containing the weights.
Arguments
dep_var
dependent variable of distributional function. Discrete or continuous numeric vector.
weights
numeric vector of non-negative observation weights, hence of same length as dep_var.
The default (NULL) is equivalent to weights = rep(1, length(dep_var)).
probs
a vector of length 2 with probabilities corresponding to the limits of the interquantile range of interest.
The interquantile range is defined as difference between the quantile with the larger probability and the one
with the lower probability.
Firpo, Sergio P., Nicole M. Fortin, and Thomas Lemieux. 2018. “Decomposing Wage Distributions Using Recentered
Influence Function Regressions.” Econometrics 6(2), 28.