Function to estimate the recentered influence function (RIF) at one or several specified quantiles
of a weighted distribution of a dependent variable.
Usage
get_rif_quantiles(dep_var, weights, probs, ...)
get_rif_quantile(dep_var, weights, probs, ...)
Value
A data frame with the number of columns equaling the length of vector probs and an additional column containing the weights.
Each column contains the RIF values at the quantile's probabilities.
Arguments
dep_var
dependent variable of a distributional function. Discrete or continuous numeric vector.
weights
numeric vector of non-negative observation weights, hence of same length as dep_var.
The default (NULL) is equivalent to weights = rep(1, length(dep_var)).
probs
the specific quantile at which to estimate the RIF.